<?php
/*
Plugin Name: Better Click To Tweet Premium Styles
Description: Add styles to your Better Click To Tweet boxes!
Version: 1.7.0
Author: Ben Meredith
Author URI: https://www.betterclicktotweet.com
Plugin URI: https://www.betterclicktotweet.com/addons/better-click-to-tweet-premium-styles
License: GPL2
Text Domain: better-click-to-tweet-premium-styles
*/


add_action( 'plugins_loaded', 'bcttps_dequeue_default_style', 100 );
add_action( 'plugins_loaded', 'bcttps_backcompat', 100 );
add_action( 'admin_notices', 'bcttps_alerts', 50 );
add_action( 'wp_enqueue_scripts', 'bcttps_enqueue_premium_style', 20 );
add_action( 'admin_init', 'bcttps_register_settings' );
add_action( 'init', 'bcttps_register_block_assets', 100 );
add_action( 'plugins_loaded', 'bcttps_set_up_constants' );

//calls the file handling all automatic add-on updates
include 'includes/updater/bcttps-updater.php';

function bcttps_set_up_constants() {

	if ( ! defined( 'BCTTPS_VERSION' ) ) {
		define( 'BCTTPS_VERSION', '1.7.0' );
	}

	// Minimum BCTT core version
	if ( ! defined( 'BCTTPS_MIN_BCTT_VERSION' ) ) {
		define( 'BCTTPS_MIN_BCTT_VERSION', '5.9.0' );
	}

	if ( ! defined( 'BCTTPS_PLUGIN_FILE' ) ) {
		define( 'BCTTPS_PLUGIN_FILE', __FILE__ );
	}
}

// For backward compatibility
function bcttps_backcompat() {
	if ( defined( 'BCTT_VERSION' ) && version_compare( BCTT_VERSION , '5.9.0', '<')) {
		add_action( 'admin_menu', 'bcttps_settings_page', 30 );
	}
}

function bcttps_register_block_assets() {
	if ( function_exists( 'register_block_type' ) ) {
		add_action( 'enqueue_block_editor_assets', 'bcttps_enqueue_block_styles' );
	}
}

/**
 *
 * This function sets all possible admin notices for the add-on.
 *
 */
function bcttps_alerts() {

	if ( ! is_plugin_active( 'better-click-to-tweet/better-click-to-tweet.php' ) && current_user_can( 'activate_plugins' ) && is_admin() ) {
		//prevents "Plugin Activated" message from showing
		echo '<style>div#message.updated{ display: none; }</style>';

		//prevents the add-on from actually being activated
		deactivate_plugins( __File__ );

		//displays an error message with instructions
		echo '<div class="error">';
		echo '<p>' . esc_html__( 'ALERT: It doesn\'t look like Better Click To Tweet is active. Before activating the Premium Styles add-on, first activate the core plugin. Thanks!', 'better-click-to-tweet-premium-styles' ) . '</p>';
		echo '</div>';

	} elseif ( isset( $_POST['bcttps-settings-saved'] ) ) {
		//shows a message when the Premium Style is updated
		add_settings_error( 'bcttps-settings', 'bcttps-style-updated', esc_html__( 'Style updated.', 'better-click-to-tweet-premium-styles' ), 'updated' );
	} else {
		$bcttpslink = plugin_basename( __FILE__ );
		add_filter( "plugin_action_links_$bcttpslink", 'bcttps_options_link' );
	}
}

/**
 *
 * This function sets an option of bctt_disable_css which is the default method for dequeueing styles built into
 * the core Better Click To Tweet plugin.
 *
 * It sets a default option of 'original' so that activating the add-on does not dequeue all styles while the user
 * selects a new style.
 *
 */
function bcttps_dequeue_default_style() {

	add_option( 'bctt_disable_css', 'yes' );
	if ( get_option( 'bcttps_custom_style' ) == false ) {
		add_option( 'bcttps_custom_style', 'original' );
	}
}

/**
 *
 * This function loops through all of the files in the /assets/css/templates directory and extracts the filename
 * (without the extension) for use as the stylesheet name, and then registers and enqueues the style based on
 * the user's selection (which is saved as an option in the wp_options database
 *
 */
function bcttps_enqueue_premium_style() {
	$dir            = plugins_url( 'assets/css/templates/', __FILE__ );
	$selected_style = get_option( 'bcttps_custom_style' );
	$css_dir        = new DirectoryIterator( dirname( __FILE__ ) . '/assets/css/templates' );

	foreach ( $css_dir as $file ) {
		if ( $file->getType() == "file" && $file !== '' ) {
			$wholename = pathinfo( $file, PATHINFO_FILENAME );
			if ( $wholename === $selected_style && $wholename != '' ) {
				wp_register_style( 'bcttps-style', $dir . $wholename . '.css' );
				wp_enqueue_style( 'bcttps-style' );
			}
		}
	}
}

function bcttps_enqueue_block_styles() {
	$dir            = plugins_url( 'assets/css/templates/', __FILE__ );
	$selected_style = get_option( 'bcttps_custom_style' );
	$css_dir        = new DirectoryIterator( dirname( __FILE__ ) . '/assets/css/templates' );

	foreach ( $css_dir as $file ) {
		if ( $file->getType() == "file" && $file !== '' ) {
			$wholename = pathinfo( $file, PATHINFO_FILENAME );
			if ( $wholename === $selected_style && $wholename != '' ) {
				wp_enqueue_style( 'bctt-block-editor-css', $dir . $wholename . '.css' );
			}
		}
	}

}
// This function is used in BCTT core to check if the plugin is active. 
// If we change to OOP or something, this needs to be changed in BCTT core with back compat.
function bcttps_register_settings() {
	register_setting( 'bcttps-options', 'bcttps_custom_style' );

}


/**
 * @return array
 */
function bcttps_get_stylesheets() {
	$dir = plugin_dir_path( __FILE__ );

	$slugs = glob( $dir . 'assets/css/templates/*.css' );

	return $slugs;

}

/**
 *
 * This section of code sets up the "Premium Styles" Admin settings page, as a submenu of the Better Click To Tweet
 * Menu Item, and sets some functions used only in that section.
 *
 */

function bcttps_settings_page() {
	add_submenu_page( 'better-click-to-tweet', 'Better Click To Tweet Premium Style Options', 'Premium Styles', 'manage_options', 'bctt_premium_styles', 'bcttps_settings_output' );
}

/**
 *
 * This function registers and enqueues the admin-only styles. it is only called on the Premium Styles settings page.
 *
 */

function bcttps_register_admin_styles() {
	wp_register_style( 'bctt-premium-style-admin', plugins_url( 'assets/css/bctt-premium-styles-admin.css', __FILE__ ) );

	wp_enqueue_style( 'bctt-premium-style-admin' );
}

/**
 * This function outputs the entire content of the Premium Styles back end settings page.
 *
 */

function bcttps_settings_output() {
	$css_dir = new DirectoryIterator( dirname( __FILE__ ) . '/assets/css/templates' );


	bcttps_register_admin_styles();

	if ( ! current_user_can( 'manage_options' ) ) {
		wp_die( __( 'You do not have sufficient permissions to access this page.', 'better-click-to-tweet' ) );
	}

	bctt_admin_styles();

	?>

    <div class="wrap">
	<?php settings_errors(); ?>
    <h1 class="wp-heading-inline"><?php /* translators: Treat "Better Click To Tweet" as a brand name, don't translate it */
		_e( 'Better Click To Tweet Premium Styles', 'better-click-to-tweet' ); ?></h1>

    <hr/>
	<?php do_action( 'bcttps_top' ); ?>


    <div id="poststuff">
        <div id="post-body" class="metabox-holder columns-2 ">
            <div id="post-body-content" style="position: relative;">
                <div id="bcttps_settings" class="postbox">
                    <h2><?php _e( 'Instructions', 'better-click-to-tweet-premium-styles' ); ?></h2>
                    <div class="inside">

                        <p><?php /* translators: Treat "Better Click To Tweet" as a brand name, don't translate it */
							_e( 'With the Premium Styles add-on for Better Click To Tweet, by selecting below, you can customize all of the Better Click To Tweet boxes on your site.', 'better-click-to-tweet-premium-styles' ); ?></p>
                    </div>
                </div>
                <div class="postbox">
                    <h2><?php _e( 'Settings', 'better-click-to-tweet-premium-styles' ); ?></h2>
                    <div class="inside">
                        <div class="main">
                            <form method="post" action="options.php" style="">
                                <table class="form-table">
                                    <tr valign="top">

										<?php settings_fields( 'bcttps-options' );
										$select_style_text = __( 'Select this style', 'better-click-to-tweet-premium-styles' );
										?>

                                        <th>
                                            <label><?php _e( 'Choose your Style', 'better-click-to-tweet-premium-styles' ) ?></label>
                                        </th>
                                        <td class="bctt-premium-style-option-original">
                                            <input type="radio" name="bcttps_custom_style"
                                                   value="original" <?php if ( get_option( 'bcttps_custom_style' ) == 'original' ) { ?> checked="checked" <?php } ?> >
                                            <label class="bcttps-option-label"> <?php echo $select_style_text ?></label>
                                            <img class="bcttps-option"
                                                 src=" <?php echo plugins_url( 'assets/images/original.png', __FILE__ ) ?> ">
                                        </td>
										<?php

										// dynamically creates the style options based on the css files in /assets/css/templates
										// and the image files (613px/318px) in assets/images. Name those files the the same, and add them,
										// and BCTTPS does the rest.

										foreach ( $css_dir as $file ) {
											if ( $file->getType() == "file" ) {

												$wholename = pathinfo( $file, PATHINFO_FILENAME );

												if ( $wholename !== '' && $wholename !== 'original' ) {
													$output = '<td class="bctt-premium-style-option-' . $wholename . '">';
													$output .= '<input type="radio" name="bcttps_custom_style" value="' . $wholename;
													if ( get_option( 'bcttps_custom_style' ) == $wholename ) {
														$output .= '" checked="checked">';
													} else {
														$output .= '">';
													}
													$output .= '<label class="bcttps-option-label">' . $select_style_text . '</label>';
													$output .= '<img class="bcttps-option"';
													$output .= 'src="' . plugins_url( 'assets/images/' . $wholename . '.png', __FILE__ ) . '">';
													$output .= '</td>';

													echo $output;
												}


											}
										} ?>


                                    </tr>

                                </table>
                                <br class="clear"/>
                                <p><input type="submit" class="button-primary" name="bcttps-settings-saved"
                                          value="<?php _e( 'Save Custom Style', 'better-click-to-tweet-premium-styles' ); ?>"/>
                                </p>
                                <br class="clear"/>
                            </form>
                        </div>
                    </div>

                </div>
			</div>
			<div id="post-box-container-1" class="post-box-container">
				<div id="side-sortables" class="meta-box-sortables ui-sortable">
					<div id="bctt-contrib" class="postbox">
					<div id="bctt-author" class="postbox " style="display:block;">
						<h2><?php _e( 'Thank You So Much!', 'better-click-to-tweet' ); ?> </h2>
						<div class="inside">
							<p><?php $url4 = 'https://www.betterclicktotweet.com/login';
								$link4        = sprintf( __( 'Your purchase of this add-on is an annual subscription that you can manage at <a href=%s>your account on our site.</a> Log in there to manage the account as well as download the latest version if automatic updates are not working.' , 'better-click-to-tweet-premium-styles' ), esc_url( $url4 ) );
								echo $link4; ?></p>
							<p><?php $url2 = 'https://twitter.com/thewpsteward';
								$link2     = sprintf( __( 'If there\'s ever anything we can do for you, reach out <a href=%s>on Twitter</a>', 'better-click-to-tweet-premium-styles' ), esc_url( $url2 ) );
								echo $link2; ?></p>
							<p><?php $url3 = 'https://benlikes.us/bcttutm';
								$link3     = sprintf( __( 'If you have any concerns about the plugin, reach out! Also be sure to check out the <a href=%s>UTM Tags add-on</a> to track how your boxes are performing.', 'better-click-to-tweet-premium-styles' ), esc_url( $url3 ) );
								echo $link3; ?></p>
						</div>
					</div>
					
				</div>						
        </div>
    </div>
	<?php

}

function bcttps_options_link( $links ) {

	$settingsText = sprintf( _x( 'Settings', 'text for the link on the plugins page', 'better-click-to-tweet-premium-styles' ) );

	$settings_link = '<a href="admin.php?page=better-click-to-tweet&tab=bctt-premium-styles">' . $settingsText . '</a>';

	array_unshift( $links, $settings_link );

	return $links;

}


function bcttps_deactivate() {
	delete_option( 'bctt_disable_css' );
	delete_option( 'bctt_style_dequeued' );
	delete_option( 'bcttps_custom_style' );
}

register_deactivation_hook( __FILE__, 'bcttps_deactivate' );

/**
 * This function adds a list of items to clean up when the Premium Styles addon is uninstalled.
 */
function bcttps_uninstall() {
	delete_option( 'bctt_disable_css' );
	delete_option( 'bctt_style_dequeued' );
	delete_option( 'bcttps_custom_style' );
}

register_uninstall_hook( __FILE__, 'bcttps_uninstall' );